__version__ = '0.0.222'

from autoweb.test import test

# import autoweb.test
#
# def test():
#     print("Hello, I'm amoblin.")
#
#
# if __name__ == '__main__':
#     test()

# pip install --upgrade -t . autoweb

__all__ = ['test']
